@@ -349,8 +349,8 @@ normTable <- function(A,
     }
 
     if(monotonuous){
-      minRawX <- normTable$raw[[1]]
-
+      if(!descend){
+        minRawX <- normTable$raw[[1]]
       for(y in 1:length(normTable$raw)){
         if(normTable$raw[[y]] >= minRawX){
           minRawX <- normTable$raw[[y]]
@@ -358,6 +358,19 @@ normTable <- function(A,
           normTable$raw[[y]] <- NA
         }
       }
+      }else{
+        y <- length(normTable$raw)
+        maxRawX <- normTable$raw[[y]]
+        while(y > 0){
+          if(normTable$raw[[y]] >= maxRawX){
+            maxRawX <- normTable$raw[[y]]
+          }else{
+            normTable$raw[[y]] <- NA
+          }
+
+          y <- y -1
+        }
+      }
     }
 
     if(rel){
